<link href="../markdown.css" rel="stylesheet"></link>

<title>2.6. 1D Wave equation: IBVP</title>

<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.0/MathJax.js?config=TeX-AMS_HTML">
    MathJax.Hub.Config({
        tex2jax: {
            inlineMath: [ ['$','$'], ["\\(","\\)"] ],
            displayMath: [ ['$$','$$'], ["\\[","\\]"] ],},
        TeX: {equationNumbers: {
            autoNumber: "AMS"
          },Augment: {  Definitions: {
           macros: {
             overbracket:  ['UnderOver','23B4',1],
             underbracket: ['UnderOver','23B5',1],
           }
         }}},
    });
</script>

$\renewcommand{\Re}{\operatorname{Re}}$
$\renewcommand{\Im}{\operatorname{Im}}$
$\newcommand{\erf}{\operatorname{erf}}$
$\newcommand{\dag}{\dagger}$
$\newcommand{\const}{\mathrm{const}}$
$\newcommand{\arcsinh}{\operatorname{arcsinh}}$


##[2.6. 1D Wave equation: IBVP](id:section-2.6)
----------------------

> 1.  [1D Wave equation on half-line](#sect-2.6.1)
> 2.  [1D Wave equation on the finite interval](#sect-2.6.2)
> 3.  [Half-line: method of continuation](#sect-2.6.3)
> 4.  [Finite interval: method of continuation](#sect-2.6.4)

###[1D Wave equation on half-line](id:sect-2.6.1)

Consider wave equation in domain  $\\{x\>0, t\>0\\}$ and initial conditions \begin{align}
&u\_{tt}-c^2 u\_{xx}=0 \qquad &&x\>0,\\ t\>0\label{eq-2.6.1}\\\\
&u|\_{t=0}=g(x) && x\>0,\label{eq-2.6.2}\\\\
&u\_t|\_{t=0}=h(x) && x\>0.\label{eq-2.6.3}
\end{align}
Here we take $f(x,t)=0$ for simplicity. Then according to the [previous section](./S2.6.html) solution $u(x,t)$ is defined uniquely in the domain $\\{t\>0, x \ge ct\\}$:

->![Figure 2.6.1](./F2.6-1.svg)<-

where it is given by D'Alembert formula
\begin{equation}
u(x,t)= \frac{1}{2}\bigl[
g(x+ct)+g(x-ct)\bigr]+\frac{1}{2c}\int\_{x-ct}^{x+ct} h(x')\,dx'.
\label{eq-2.6.4}
\end{equation}
What about domain $\\{0 \< x \< ct\\} $? We claim that *we need one boundary condition as $x=0, t\>0$*. Indeed, recall that the general solution of (\ref{eq-2.6.1}) is
\begin{equation}
u(x,t)= \phi (x+ct)+\psi (x-ct)
\label{eq-2.6.5}
\end{equation}
where initial conditions (\ref{eq-2.6.2})-(\ref{eq-2.6.3}) imply that
\begin{align\*}
&\phi(x)+\psi(x)= g(x),\\\\
&\phi (x)-\psi(x)=\frac{1}{c}\int^x\_0 h(x')\,dx'
\end{align\*}
as $x\>0$ (where we integrated the second equation) and then
\begin{align}
&\phi(x)= \frac{1}{2}g(x)+\frac{1}{2c}\int^x \_0 h(x')\,dx',\qquad &&x\>0,\label{eq-2.6.6}\\\\
&\psi(x)=\frac{1}{2}g(x)-\frac{1}{2c}\int^x \_0 h(x')\,dx' \qquad&&x\>0. \label{eq-2.6.7}
\end{align}
Therefore, $\phi(x+ct)$ and $\psi(x-ct)$ are defined respectively as $x+ct\>0$ (which is automatic as $x\>0,t\>0$) and $x-ct\<0$ (which is fulfilled only as $x\>ct$).

To define $\psi(x-ct)$ as $0\< x \< ct$ we need to define $\psi(x)$ as $x\<0$ and we need a boundary condition as $x=0,t\>0$.

**[Example 1.](id:example-2.6.1)** Consider *Dirichlet boundary condition*
\begin{equation}
u|\_{x=0}= p(t), \qquad t\>0.
\label{eq-2.6.8}
\end{equation}
Plugging (\ref{eq-2.6.4}) we see that $\phi(ct)+\psi(-ct)=p(t)$ as $t\>0$ or equivalently $\phi(-x)+\psi(x)=p(-x/c)$ as $x\<0$ (and $-x\>0$) where we plugged $t:=-x/c$. Plugging (\ref{eq-2.6.6}) we have
\begin{multline}
\psi(x)=p(-x/c)-\phi(x)=\\\\
p(-x/c)-\frac{1}{2}g(-x) -\frac{1}{2c}\int\_0^{-x} h(x')\,dx'.
\qquad \label{eq-2.6.9}
\end{multline}
Then plugging $x:=x+ct$ into (\ref{eq-2.6.6}) and $x:=x-ct$ into (\ref{eq-2.6.9}) and adding we get from (\ref{eq-2.6.4}) that
\begin{multline}
u(x,t)=
\underbracket{\frac{1}{2}g(x+ct)+
\frac{1}{2c}\int\_0^{x+ct}h(x')\,dx'}\_{=\phi(x+ct)}+ \\\\
\underbracket{p(t-x/c)-\frac{1}{2}g(ct-x)
-\frac{1}{2c}\int\_0^{ct-x} h(x')\,dx'}\_{=\psi(x-ct)}. \qquad
\label{eq-2.6.10}
\end{multline}
This formula defines $u(x,t)$ as $0\< x\< ct$ solution is given by (\ref{eq-2.6.4}).

a.  As $g=h=0$ (wave is generated by the perturbation of the end)
    \begin{equation}
    u(x,t)= \left\\{\begin{aligned}
     & 0\qquad && 0 \< ct \< x,\\\\
     & p(t-x/c) \qquad && 0 \< x \< ct.
    \end{aligned}\right.
    \label{eq-2.6.11}
    \end{equation}
b.  As $g(x)=\phi(x)$, $h(x)=c\phi'(x)$ , $p=0$ (wave initially
    running to the left and then reflected)
    \begin{equation}
    u(x,t)=\left\\{ \begin{aligned}
    & \phi(x+ct)\qquad && 0 \< ct \< x,\\\\
    & \phi(x+ct)-\phi(ct-x) && 0 \< x \< ct;
    \end{aligned}\right.
    \label{eq-2.6.12}
    \end{equation}
<!--\end{example}-->

**[Example 2.](id:example-2.6.2)** Alternatively, consider *Neumann boundary condition*
\begin{equation}
u\_x|\_{x=0}= q(t), \qquad t\>0.
\label{eq-2.6.13}
\end{equation}

Plugging (\ref{eq-2.6.4}) we see that $\phi'(ct)+\psi'(-ct)=q(t)$ as
$t\>0$ or equivalently $\phi(-x)-\psi(x)=c\int\_0^{-x/c}q(t')\,dt'$ as $x\< 0$ (and $-x\>0$) where we integrated first and then plugged $t:=-x/c$.

Plugging (\ref{eq-2.6.6}) we have
\begin{multline}
\psi(x)=-c\int\_0^{-x/c}q(t')\,dt'+\phi(x)=\\\\
-c\int\_0^{-x/c}q(t')\,dt'+\frac{1}{2}g(-x) +
\frac{1}{2c}\int\_0^{-x}
h(x')\,dx'.
\qquad \label{eq-2.6.14}
\end{multline}
Then plugging $x:=x+ct$ into (\ref{eq-2.6.6}) and $x:=x-ct$ into (\ref{eq-2.6.14}) and adding we get from (\ref{eq-2.6.4}) that
\begin{multline}
u(x,t)=
\underbracket{\frac{1}{2}g(x+ct)+
\frac{1}{2c}\int\_0^{x+ct}h(x')\,dx'}\_{=\phi(x+ct)}+ \\\\
\underbracket{-c\int \_0^{t-x/c}q(t')\,dt'+\frac{1}{2}g(ct-x)
+\frac{1}{2c}\int\_0^{ct-x} h(x')\,dx'}\_{=\psi(x-ct)}.
\qquad\label{eq-2.6.15}
\end{multline}
This formula defines $u(x,t)$ as $0\< x\< ct$. Recall that for $x\> ct$ solution is given by (\ref{eq-2.6.4}).

In particular

a.  As $g=h=0$ (wave is generated by the perturbation of the end)
    \begin{equation}
    u(x,t)= \left\\{\begin{aligned}
    & 0\qquad && 0\< ct \< x,\\\\
    & -c\int\_0^{t-x/c} && 0 \< x \< ct.
    \end{aligned}\right.
    \label{eq-2.6.16}
    \end{equation}
b.  As $g(x)=\phi(x)$, $h(x)=c\phi'(x)$ , $p=0$ (wave initially running to the left and then reflected)
    \begin{equation}
    u(x,t)= \left\\{ \begin{aligned}
    & \phi(x+ct)\qquad && 0 \< ct \< x,\\\\
    & \phi(x+ct)+\phi(ct-x) && 0 \< x \< ct;
    \end{aligned}\right.
    \label{eq-2.6.17}
    \end{equation}
<!--\end{example}-->

**[Example 3.](id:example-2.6.3)** Alternatively, consider boundary condition
\begin{equation}
(\alpha u\_x+\beta u\_t)|\_{x=0}= q(t), \qquad t\>0.
\label{eq-2.6.18}
\end{equation}
Again we get equation to $\psi(-ct)$:
$(\alpha -c \beta)\psi'(-ct)+ (\alpha +c \beta) \phi' (ct)=q(t) $ and everything works well as long as $\alpha\ne c\beta $.
<!--\end{example}-->

**[Example 4.](id:example-2.6.4)** Alternatively, consider *Robin boundary condition*
\begin{equation}
(u\_x+\sigma u)|\_{x=0}= q(t), \qquad t\>0.
\label{eq-2.6.19}
\end{equation}
and we get $ \psi'(-ct)+\sigma \psi (-ct) + \phi'(ct)+\sigma \phi (ct)=q(t)$ or equivalently
\begin{equation}
\psi'(x)+\sigma \psi (x)=q(-x/c)- \phi'(-x)+\sigma \phi (-x)
\label{eq-2.6.20}
\end{equation} where the right-hand expression is known.

In this case we define $\psi(x)$ as $x\<0$ solving ODE (\ref{eq-2.6.20}) as we know $\psi(0)=\frac{1}{2}g(0)$ from (\ref{eq-2.6.7}).
<!--\end{example}-->

###[1D Wave equation on the finite interval](id:sect-2.6.2)

Consider wave equation in domain $\\{a\< x\< b, t\>0\\}$ and initial conditions \begin{align}
&u\_{tt}-c^2 u\_{xx}=0 \qquad
&&a\<x\<b,\ t\>0\label{eq-2.6.21}\\\\
&u|\_{t=0}=g(x) && a\< x\< b, \label{eq-2.6.22}\\\\
&u\_t|\_{t=0}=h(x) && a\< x\< b.\label{eq-2.6.23}
\end{align}
Here we take $f(x,t)=0$ for simplicity. Then according to the [previous section](./S2.6.html) solution $u(x,t)$ is defined uniquely in the characteristic triangle $ABC$.

->![Fig-2.6.2](./SF.6-2.svg)<-

a.  However $\phi (x)$, $\psi(x)$ are defined as $a\< x\< b$.
b.  Now the boundary condition on the left end (f. e.
    $u|\_{x=a}=p\_l(t)$, or $u\_x|\_{x=a}=q\_l(t)$, or more general
    condition) allows us to find $\psi (a-ct)$ as $0\< t\< (b-a)/c$
    and then $\psi(x-ct)$ is defined in $ABB'';A'$. Similarly the
    boundary condition on the right end (f. e. $u|\_{x=b}=p\_r(t)$, or
    $u\_x|\_{x=a}=q\_r(t)$, or more general condition) allows us to
    find $\phi (b+ct)$ as $0\< t\< (b-a)/c$ and then $\phi(x+ct)$
    is defined in $ABB'A''$. So, $u$ is defined in the intersection
    of those two domains which is $AA'C'B'B$.

c.  Continuing this process in steps we define $\phi (x+ct)$, $\psi
    (x-ct)$ and $u(x,t)$ in expanding "up" set of domains.


###[Half-line: method of continuation](id:sect-2.6.3)

Consider wave equation in domain $\\{x\>0, t\>0\\}$, initial conditions, and a boundary condition
\begin{align}
&u\_{tt}-c^2 u\_{xx}=f(x,t) \qquad &&x\>0, \label{eq-2.6.24}\\\\
&u|\_{t=0}=g(x) && x\>0,\label{eq-2.6.25}\\\\
&u\_t|\_{t=0}=h(x) && x\>0,\label{eq-2.6.26} \\\\
&u|\_{x=0}=0. \label{eq-2.6.27}
\end{align}
Alternatively, instead of (\ref{eq-2.6.27}) we consider
\begin{align}
& u\_x |\_{x=0}=0.\qquad&&\qquad\quad \tag\*{$(2.6.27)'$}\label{eq-2.6.27-'}
\end{align}

**[Remark 1.](id:remark-2.6.1)**
It is crucial that we consider either Dirichlet or Neumann homogeneous boundary conditions.
<!--\end{remark}-->
To deal with this problem consider first IVP on the whole line:
\begin{align}
&U\_{tt}-c^2 U\_{xx}=F(x,t) \qquad &&x\>0,\label{eq-2.6.28}\\\\
&U|\_{t=0}=G(x) && x\>0,\label{eq-2.6.29}\\\\
&U\_t|\_{t=0}=H(x) && x\>0,\label{eq-2.6.30} 
\end{align}
and consider $V(x,t)= \varsigma U(-x,t)$ with $\varsigma =\pm 1$.

**[Proposition 1.](id:proposition-2.6.1)**
If $U$ satisfies (\ref{eq-2.6.28})-(\ref{eq-2.6.30}) then $V$ satisfies similar problem albeit with right-hand expression $\varsigma F(-x,t)$, and initial functions $\varsigma G(-x)$ and $\varsigma H(-x)$.
<!--\end{proposition}-->

*Proof.*
Plugging $V$ into equation we use the fact that
$V\_t(x,t)=\varsigma U\_t (-x,t)$, $V\_x(x,t)=-\varsigma U\_x
(-x,t)$, $V\_{tt}(x,t)=\varsigma U\_{tt} (-x,t)$,
$V\_{tx}(x,t)=-\varsigma U\_{tx} (-x,t)$,
$V\_{xx}(x,t)=\varsigma U\_{xx} (-x,t)$ etc and exploit the fact that wave equation contains only even-order derivatives with respect to $x$.

Note that if $F,G,H$ are even functions with respect to $x$, and $\varsigma=1$ then $V(x,t)$ satisfies the same IVP as $U(x,t)$. Similarly, if $F,G,H$ are odd functions with respect to $x$, and $\varsigma=-1$ then $V(x,t)$ satisfies the same IVP as $U(x,t)$.

However we know that solution of (\ref{eq-2.6.28})-(\ref{eq-2.6.30}) is unique
and therefore $U(x,t)=V(x,t)=\varsigma U(-x,t)$.
<!--\end{proof}-->

Therefore

**[Corollary 1.](id:corollary-2.6.1)**

a.  If $\varsigma=-1$ and $F,G,H$ are odd functions with respect
    to $x$ then $U(x,t)$ is also an odd function with respect to
    $x$.

b. If $\varsigma=1$ and $F,G,H$ are even functions with respect
    to $x$ then $U(x,t)$ is also an even function with respect to
    $x$.
<!--\end{corollary}-->

However we know that
	a. odd function with respect to $x$ vanishes as $x=0$;
	b. derivative of the even function with respect to $x$ vanishes as $x=0$

and we arrive to

**[Corollary 2.](id:corollary-2.6.2)**

a.  In the framework of Proposition 1a $U$ satisfies (\ref{eq-2.6.27});
b.  In the framework of Proposition 1b $U$ satisfies \ref{eq-2.6.27-'}.
<!--\end{corollary}-->

Therefore

**[Corollary 3.](id:corollary-2.6.3)**
	a. To solve (\ref{eq-2.6.24})-(\ref{eq-2.6.26}), (\ref{eq-2.6.27}) we need to take an odd continuation of $f,g,h$ to $x\<0$ and solve the corresponding IVP;
	b. To solve (\ref{eq-2.6.24})-(\ref{eq-2.6.26}),
\ref{eq-2.6.27-'} we need to take an even continuation of $f,g,h$ to $x\<0$ and solve the corresponding IVP.
<!--\end{corollary}-->

So far we have not used much that we have exactly wave equation (similar
argments with minor modification work for heat equation as well etc). Now we apply D'Alembert formula ([2.5.4](./S2.5.html##mjx-eqn-eq-2.5.4)):
\begin{multline\*}
u(x,t)= \frac{1}{2}\bigl( G(x+ct)+G(x-ct) \bigr)
+ \frac{1}{2c}\int\_{x-ct} ^{x+ct} H(x')\,dx' +\\\\
\frac{1}{2c} \int\_0^t \int \_{x-c(t-t')} ^{x+c(t-t')} F(x',t')\, dx' dt'
\end{multline\*}
and we need to take $0\< x\< ct$, resulting for $f=0\implies F=0$ \begin{equation}
u(x,t)=  \frac{1}{2}\bigl( g(ct+x)- g(ct-x) \bigr) +
\frac{1}{2c}\int\_{ct-x} ^{ct+x} h(x')\,dx' ,\qquad
\label{eq-2.6.31}
\end{equation}
and
\begin{multline}
u(x,t)= \frac{1}{2}\bigl( g(ct+x)+ g(ct-x) \bigr) +\\\\
\frac{1}{2c}\int\_0 ^{ct-x} h(x')\,dx' +
\frac{1}{2c}\int\_0 ^{ct+x} h(x')\,dx'\qquad
\tag\*{(31)'}\label{eq-2.6.31-'}
\end{multline} for boundary condition (\ref{eq-2.6.27}) and \ref{eq-2.6.27-'} respectively.

**[Example 5.](id:example-2.6.5)** Consider wave equation with $c=1$ and let $f=0$,

a.  $g= \sin (x)$, $h=0$ and Dirichlet boundary condition.
    Obviously $G(x)=\sin (x)$ (since we take odd continuation and
    $\sin(x)$ is an odd function). Then
    \begin{equation}
    u(x,t)=\frac{1}{2}\bigl( \sin (x+t)+\sin (x-t)\bigr)= \sin (x)\cos (t).
    \label{eq-2.6.32}
    \end{equation}
b.  $g= \sin (x)$, $h=0$ and Neumann boundary condition. Obviously
    $G(x)=-\sin (x)$ as $x\<0$ (since we take even continuation and
    $\sin(x)$ is an odd function). Then $u$ is given by (\ref{eq-2.6.32}) for
    $x\ >t\ >0$ and
    \begin{equation}
    u(x,t)=\frac{1}{2}\bigl( \sin (x+t)-\sin (x-t)\bigr)= \sin (t)\cos(x)
    \label{eq-2.6.33}
    \end{equation} as $0\< x\< t$.
c.  $g= \cos (x)$, $h=0$ and Neumann boundary condition. Obviously
    $G(x)=\cos (x)$. Then
    \begin{equation}
    u(x,t)=\frac{1}{2}\bigl( \cos (x+t)+\cos (x-t)\bigr)= \cos (x)\cos (t).
    \label{eq-2.6.34}
    \end{equation}
d.  $g= \cos (x)$, $h=0$ and Dirichlet boundary condition.
    Obviously $G(x)=-\cos (x)$ as $x\<0$. Then $u$ is given by
    (\ref{eq-2.6.35}) for $x\>t\>0$ and
    \begin{equation}
    u(x,t)=\frac{1}{2}\bigl( \cos (x+t)-\cos (x-t)\bigr)= \sin (t)\sin (x)
     \label{eq-2.6.35}
     \end{equation} as $0\< x\< t$.
<!--\end{example}-->

###[Finite interval: method of continuation](id:sect-2.6.4)

Consider the same problem albeit on interval $0\< x\< l$ with either Dirichlet or Neumann condition on each end. Then we need to take odd continuation through "Dirichlet end" and even continuation through "Neumann end". On figures below we have respectively Dirichlet conditions on each end (indicated by red), Neumann conditions on each end (indicated by green), and Dirichlet condition on one end (indicated by red) and Neumann conditions on another end (indicated by green).
Resulting continuations are $2l$, $2l$ and $4l$ periodic
respectively.

->![Fig-2.6.3](./F2.6-3.svg)<-


______________

[$\Uparrow$](../contents.html)&nbsp;&nbsp;[$\uparrow$](./S2.7.html)&nbsp;&nbsp;[$\downarrow$](./S2.6.P.html)&nbsp;&nbsp;[$\Rightarrow$](./S2.8.html)
